Compound

Struct Compound 

pub struct Compound<'a> { /* private fields */ }
Represents TAG_Compound, a list of key/value pairs. The order of the entries is the same that they appear in the file, although this usually is not significant.

Example

if let Some(entry) = compound.find_first_key("Health") {
    if let Some(health) = entry.value().to_i64() {
        println!("Player has {} health", health);
    }
}

Implementations

Source

impl<'a> Compound<'a>

pub fn len(&self) -> usize

Returns the number of entries.

pub fn is_empty(&self) -> bool

Returns true if there are no entries.

pub fn into_vec(self) -> Vec<Entry<'a>>

Converts into a Vec of key/value pairs.

pub fn find_first_key(&self, key: &str) -> Option<&Entry<'a>>

Searches for the first key that matches the input, and returns it if it exists.

pub fn iter(&self) -> SliceIter<'_, Entry<'a>>

Returns an iterator over the entries.

pub fn entries(&self) -> &[Entry<'a>]