pub struct Compound<'a> { /* private fields */ }Expand description
Represents TAG_Compound, a list of key/value pairs. The order of the entries is the same that they appear in the file, although this usually is not significant.
Example
if let Some(entry) = compound.find_first_key("Health") {
if let Some(health) = entry.value().to_i64() {
println!("Player has {} health", health);
}
}Implementations